--- a/sysstatemgmt/syslangutil/ssmlangselcmd/inc/ssmlanguageloader.h Thu Aug 19 11:09:10 2010 +0300
+++ b/sysstatemgmt/syslangutil/ssmlangselcmd/inc/ssmlanguageloader.h Tue Aug 31 16:29:05 2010 +0300
@@ -1,5 +1,5 @@
/*
-* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
* All rights reserved.
* This component and the accompanying materials are made available
* under the terms of "Eclipse Public License v1.0"
@@ -11,8 +11,7 @@
*
* Contributors:
*
-* Description:
-* Declaration of SsmLanguageLoader class.
+* Description: Declaration of SsmLanguageLoader class.
*
*/
@@ -34,15 +33,15 @@
public:
/**
* Store language code to HAL and load corresponding locale DLL.
*
* @since S60 3.2
* @param aLanguage Language code identifying which locale DLL to load.
* @return KErrNone if loading was successful, one of Symbian error codes
* otherwise.
*/
- static TInt LoadLanguage( const TInt aLanguage );
-
+ static TInt LoadLocale( const TInt aLanguage, const TInt aRegion, const TInt aCollation);
private:
/**
@@ -55,23 +54,13 @@
static TInt StoreLanguageToHal( const TInt aLanguage );
/**
- * Find the correct locale DLL to use by language code and take it to
- * use.
+ * Loads the given Language, Region and Collation DLLs and saves the settings
*
- * @param aLanguageCode The language code to find a locale dll for.
+ * @param aLanguageDllName The name of the Language DLL to load.
+ * @param aRegionDllName The name of the Region DLL to load.
+ * @param aCollationDllName The name of the Collation DLL to load.
* @return KErrNone if successful, one of Symbian error codes otherwise.
*/
- static TInt LoadLocaleDll( const TInt aLanguage );
-
- /**
- * Take a locale DLL to use by name.
- *
- * @param aLocaleDllName The name of the locale DLL to load.
- * @return KErrNone if successful, one of Symbian error codes otherwise.
- */
- static TInt ChangeLocale( const TDesC& aLocaleDllName );
-
+ static TInt ChangeLocale( const TDesC& aLanguageDllName, const TDesC& aRegionDllName, const TDesC& aCollationDllName );
};
-
-
#endif // SSMLANGUAGELOADER_H
@@ -34,15 +33,15 @@
public:
/**
- * Store language code to HAL and load corresponding locale DLL.
+ * Store language code to HAL and load corresponding Language, Region and Collation DLLs.
*
@@ -34,15 +33,15 @@
*
- * @since S60 3.2
- * @param aLanguage Language code identifying which locale DLL to load.
+ * @param aLanguage Language code identifying which language DLL to load.
+ * @param aRegion Region code identifying which region DLL to load.
+ * @param aCollation Collation code identifying which collation DLL to load.
* @return KErrNone if loading was successful, one of Symbian error codes
* otherwise.